@@ -2,7 +2,7 @@
 It's my first module, so let me know if I get something wrong about Python
 """
 
-def print_lol(the_list,identation):
+def print_lol(the_list,identation=0):
     """ This function prints all items of a list in the standard output (console)
 	It also prints items of nested items. It does recursively (which is always awesome). """
     for item in the_list:
